@@ -30,4 +30,4 @@ class ReadAllLogsFileIntoMemoryUsingPandas:
 
     def get_files_list(self, files_pattern: object) -> list[str]:
         files = glob.glob(files_pattern)
-        return files
+        return files[:1]
